# Comparing LLM and human behavior

SweetBean experiments can be run online or with via language models. This makes SweetBean a convenient package to collect data from real participants and compare it to data generated by language models. For example, to finetune a model on the collected data for alignment.